@@ -13,7 +13,7 @@
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 
-Version = '2.0'
+Version = '2.1'
 
 import os
 import sys
@@ -26,7 +26,7 @@ from CSSUfeaturesUI import *
 
 #############################################################################################################
 
-PathApp             = '/opt/CSSUfeatures/'             # application path
+PathApp             = '/opt/CSSUfeatures/'            # application path
 PathSystem          = '/usr/share/hildon-desktop/'    # main path
 ConfigSystem        = 'transitions.ini'               # name of system config file
 PathTheme           = '/etc/hildon/theme/'            # main path (if themes are in place)
@@ -243,7 +243,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              QtGui.QWidget.__init__(self, parent)
              self.ui = Ui_CSSUfeaturesUI()
              self.ui.setupUi(self)
-             #self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+             self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
              self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
              
              ##Connect the GUI Buttons with actions
@@ -507,9 +507,9 @@ class CSSUfeaturesMain():
      
      ##Check if CSSU is installed
      if checkCSSUinstalled() == False:
-         message = 'ERROR: The Community SSU is not installed.\n\nExiting..'
+         message = 'ERROR: The Community SSU is not installed.\nSome features might not work correctly..'
          showMessage(message)
-         sys.exit(1)
+         #sys.exit(1)
      else:
          pass
      
